@@ -173,20 +173,36 @@ func (t *UnionType) ConversionFrom(src Type) ConversionKind {
 	return kind
 }
 
-func (t *UnionType) conversionFrom(src Type, unifying bool, seen map[Type]struct{}) (ConversionKind, hcl.Diagnostics) {
-	return conversionFrom(t, src, unifying, seen, func() (ConversionKind, hcl.Diagnostics) {
+func (t *UnionType) conversionFrom(src Type, unifying bool, seen map[Type]struct{}) (ConversionKind, lazyDiagnostics) {
+	return conversionFrom(t, src, unifying, seen, func() (ConversionKind, lazyDiagnostics) {
 		var conversionKind ConversionKind
-		var diags hcl.Diagnostics
+		var diags []lazyDiagnostics
+
+		// Fast path: see if the source type is equal to any of the element types. Equality checks are generally
+		// less expensive that full convertibility checks.
+		for _, t := range t.ElementTypes {
+			if src.Equals(t) {
+				return SafeConversion, nil
+			}
+		}
+
 		for _, t := range t.ElementTypes {
 			ck, why := t.conversionFrom(src, unifying, seen)
 			if ck > conversionKind {
 				conversionKind = ck
-			} else {
-				diags = diags.Extend(why)
+			} else if why != nil {
+				diags = append(diags, why)
 			}
 		}
 		if conversionKind == NoConversion {
-			return NoConversion, diags
+			return NoConversion, func() hcl.Diagnostics {
+				var all hcl.Diagnostics
+				for _, why := range diags {
+					//nolint:errcheck
+					all.Extend(why())
+				}
+				return all
+			}
 		}
 		return conversionKind, nil
 	})
@@ -195,7 +211,7 @@ func (t *UnionType) conversionFrom(src Type, unifying bool, seen map[Type]struct
 // If all conversions to a dest type from a union type are safe, the conversion is safe.
 // If no conversions to a dest type from a union type exist, the conversion does not exist.
 // Otherwise, the conversion is unsafe.
-func (t *UnionType) conversionTo(dest Type, unifying bool, seen map[Type]struct{}) (ConversionKind, hcl.Diagnostics) {
+func (t *UnionType) conversionTo(dest Type, unifying bool, seen map[Type]struct{}) (ConversionKind, lazyDiagnostics) {
 	conversionKind, exists := SafeConversion, false
 	for _, t := range t.ElementTypes {
 		switch kind, _ := dest.conversionFrom(t, unifying, seen); kind {
