@@ -98,14 +98,29 @@ namespace Pulumi.Serialization
             if (targetType == typeof(object))
                 return (val, null);
 
-            if (targetType == typeof(Asset))
-                return TryEnsureType<Asset>(context, val);
+            if (targetType == typeof(Asset)) {
+                var (d, exception) = TryEnsureType<Asset>(context, val);
+                if (exception != null) {
+                    d = new InvalidAsset();
+                }
+                return (d, null);
+            }
 
-            if (targetType == typeof(Archive))
-                return TryEnsureType<Archive>(context, val);
+            if (targetType == typeof(Archive)) {
+                var (d, exception) = TryEnsureType<Archive>(context, val);
+                if (exception != null) {
+                    d = new InvalidArchive();
+                }
+                return (d, null);
+            }
 
-            if (targetType == typeof(AssetOrArchive))
-                return TryEnsureType<AssetOrArchive>(context, val);
+            if (targetType == typeof(AssetOrArchive)) {
+                var (d, exception) = TryEnsureType<AssetOrArchive>(context, val);
+                if (exception != null) {
+                    d = new InvalidAsset();
+                }
+                return (d, null);
+            }
 
             if (targetType == typeof(JsonElement))
                 return TryConvertJsonElement(context, val);
